pub struct ReactiveQuery<R, F> { /* private fields */ }Expand description
A live query over a document: re-evaluates query when the document changes
and yields the new result only when it differs from the last emitted one.
Implementations
Sourceimpl<R, F> ReactiveQuery<R, F>
impl<R, F> ReactiveQuery<R, F>
Sourcepub fn new(doc: &CrdtDoc, query: F) -> Self
pub fn new(doc: &CrdtDoc, query: F) -> Self
Build a reactive query over doc, evaluating query once for the initial
value.